@@ -82,7 +82,7 @@ class Ranger21(Optimizer):
         decay_type: str = 'stable',
         warmup_type: str = 'linear',
         warmup_pct_default: float = 0.22,
-        logging_active: bool = True,
+        logging_active: bool = False,
     ):
         """Ranger optimizer (RAdam + Lookahead + Gradient Centralization, combined into one optimizer)
         :param params: PARAMS. iterable of parameters to optimize or dicts defining parameter groups
@@ -144,24 +144,26 @@ class Ranger21(Optimizer):
         self.total_iterations: int = num_epochs * num_batches_per_epoch
         if not self.total_iterations:
             raise ValueError(
-                'missing total iterations, which is calculated from num epochs and num iterations per epoch param'
+                'missing total iterations, '
+                'calculated from num epochs and num iterations per epoch param'
             )
 
-        # lr
         self.starting_lr = lr
         self.current_lr = lr
 
-        # warmup - we'll use default recommended in Ma/Yarats unless user specifies num iterations
+        # warmup - we'll use default recommended in Ma/Yarats
+        # unless user specifies num iterations
         self.use_warmup = use_warmup
-        self.warmup_complete = False
         self.warmup_type = warmup_type
         self.warmup_pct_default = warmup_pct_default
+        self.warmup_complete: bool = False
 
         if num_warmup_iterations is None:
             beta_warmup_iterations: int = math.ceil((2 / (1 - betas[1])))
             beta_pct: float = beta_warmup_iterations / self.total_iterations
 
-            # this can be unreasonable for short runs...so let's compare vs warmup pct % of total epochs
+            # this can be unreasonable for short runs...
+            # so let's compare vs warmup pct % of total epochs
             if beta_pct > 0.45:
                 warmup_auto_pct = int(
                     self.warmup_pct_default * self.total_iterations
@@ -351,7 +353,7 @@ class Ranger21(Optimizer):
                 loss = closure()
 
         param_size: float = 0
-        variance_ma_sum: float = 0.0
+        variance_ma_sum: float = 1.0
 
         # phase 1 - accumulate all of the variance_ma_sum to use in stable weight decay
         for i, group in enumerate(self.param_groups):
@@ -359,10 +361,8 @@ class Ranger21(Optimizer):
                 if p.grad is None:
                     continue
 
-                # if not self.param_size:
                 param_size += p.numel()
 
-                # apply agc if enabled
                 if self.agc_active:
                     agc(
                         p, agc_eps=self.agc_eps, agc_clip_val=self.agc_clip_val
@@ -375,43 +375,27 @@ class Ranger21(Optimizer):
 
                 state = self.state[p]
 
-                # State initialization
                 if len(state) == 0:
                     state['step'] = 0
-
-                    # Exponential moving average of gradient values
-                    state['grad_ma'] = torch.zeros_like(
-                        p, memory_format=torch.preserve_format
-                    )
-                    # Exponential moving average of squared gradient values
-                    state['variance_ma'] = torch.zeros_like(
-                        p, memory_format=torch.preserve_format
-                    )
+                    state['grad_ma'] = torch.zeros_like(p)
+                    state['variance_ma'] = torch.zeros_like(p)
 
                     if self.lookahead_active:
                         state['lookahead_params'] = torch.zeros_like(p.data)
                         state['lookahead_params'].copy_(p.data)
 
                     if self.use_adabelief:
-                        state['variance_ma_belief'] = torch.zeros_like(
-                            p, memory_format=torch.preserve_format
-                        )
+                        state['variance_ma_belief'] = torch.zeros_like(p)
                     if self.momentum_pnm:
-                        state['neg_grad_ma'] = torch.zeros_like(
-                            p, memory_format=torch.preserve_format
-                        )
+                        state['neg_grad_ma'] = torch.zeros_like(p)
+                        state['max_variance_ma'] = torch.zeros_like(p)
 
-                        # Maintains max of all exp. moving avg. of sq. grad. values
-                        state['max_variance_ma'] = torch.zeros_like(
-                            p, memory_format=torch.preserve_format
-                        )
-
-                # centralize gradients
                 if self.use_gc:
                     grad = centralize_gradient(
                         grad,
                         gc_conv_only=self.gc_conv_only,
                     )
+
                 if self.use_gc_norm:
                     grad = normalize_gradient(grad)
 
@@ -497,11 +481,11 @@ class Ranger21(Optimizer):
                     p.data.mul_(1 - decay * _lambda / variance_normalized)
 
             if self.norm_loss_active:
-                unorm = unit_norm(p.data)
+                u_norm = unit_norm(p.data)
                 correction = (
                     2
                     * self.norm_loss_factor
-                    * (1 - torch.div(1, unorm + self.eps))
+                    * (1 - torch.div(1, u_norm + self.eps))
                 )
                 p.mul_(1 - lr * correction)
 
@@ -550,10 +534,8 @@ class Ranger21(Optimizer):
                     if self.softplus:
                         rms = F.softplus(rms, beta=self.beta_softplus)
 
-                    # Update s
                     s.data.add_(inner_grad, alpha=_lambda)
 
-                    # Step
                     if momentum == 0:
                         p.data.copy_(x0.addcdiv(s, rms, value=-1))
                     else:
@@ -561,13 +543,11 @@ class Ranger21(Optimizer):
 
                         # p is a moving average of z
                         p.data.mul_(1 - ck).add_(z, alpha=ck)
-                else:  # adam with pnm core
+                else:
                     grad = p.grad
                     beta1, beta2 = group['betas']
                     grad_ma = state['grad_ma']
                     variance_ma = state['variance_ma']
-                    if self.use_adabelief:
-                        variance_ma_belief = state['variance_ma_belief']
 
                     if self.momentum_pnm:
                         max_variance_ma = state['max_variance_ma']
